@@ -50,14 +50,40 @@ typedef struct
 } MemMapsData;
 
 
+/*
+ * Tries to guess memory format.
+ * 32bits processes running on a 64bit kernel may have 64bit VM values.
+ */
+
+static const char *
+get_memory_format(void)
+{
+	static const char *format;
+
+	if (G_UNLIKELY(!format)) {
+		glibtop_map_entry *memmaps;
+		glibtop_proc_map procmap;
+
+		memmaps = glibtop_get_proc_map(&procmap, getpid());
+
+		if (sizeof(void*) == 8 || memmaps[procmap.number - 1].end > G_MAXUINT32)
+			format = "%016llx";
+		else
+			format = "%08llx";
+
+		g_free(memmaps);
+	}
+
+	return format;
+}
+
 
 /*
  * Returns a new allocated string representing @v
  */
 static gchar* vmoff_tostring(guint64 v)
 {
-	return g_strdup_printf((sizeof (void*) == 8) ? "%016llx" : "%08llx",
-			       (sizeof (void*) == 8) ?  v : v & 0xffffffff);
+	return g_strdup_printf(get_memory_format(), v);
 }
 
 
@@ -162,7 +188,8 @@ compare_memmaps (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpoi
 
 	gtk_tree_model_get (model, iter, MMAP_COL_VMSTART, &old_name, -1);
 
-	g_return_val_if_fail(old_name != NULL, FALSE);
+	if (!old_name)
+		return FALSE;
 
 	/* If the glibtop_map_entry is still there, we remove it
 	   from the new_maps so it's going to be updated only.
@@ -191,7 +218,7 @@ update_memmaps_dialog (MemMapsData *mmdata)
 	GtkTreeModel *model;
 	glibtop_map_entry *memmaps;
 	glibtop_proc_map procmap;
-	gint i;
+	guint i;
 
 	memmaps = glibtop_get_proc_map (&procmap, mmdata->info->pid);
 	/* process has disappeared */
@@ -328,10 +355,28 @@ create_memmapsdata (ProcData *procdata)
 
 		cell = gtk_cell_renderer_text_new ();
 
+		switch (i) {
+		case MMAP_COL_VMSTART:
+		case MMAP_COL_VMEND:
+		case MMAP_COL_FLAGS:
+		case MMAP_COL_VMOFFSET:
+		case MMAP_COL_DEVICE:
+			g_object_set(cell, "family", "monospace", NULL);
+			break;
+		}
+
+		switch (i) {
+		case MMAP_COL_INODE:
+		case MMAP_COL_VMSZ:
+			g_object_set(cell, "xalign", 1.0f, NULL);
+			break;
+		}
+
 		column = gtk_tree_view_column_new_with_attributes (titles[i],
 								   cell,
 								   "text", i,
 								   NULL);
+
 		gtk_tree_view_column_set_sort_column_id (column, i);
 		gtk_tree_view_column_set_resizable (column, TRUE);
 		gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
@@ -373,7 +418,7 @@ memmaps_timer (gpointer data)
 	GtkTreeModel *model;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (mmdata->tree));
-	g_return_val_if_fail (model, FALSE);
+	g_assert(model);
 
 	update_memmaps_dialog (mmdata);
 
@@ -394,7 +439,9 @@ create_single_memmaps_dialog (GtkTreeModel *model, GtkTreePath *path,
 	ProcInfo *info;
 
 	gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
-	g_return_if_fail (info);
+
+	if (!info)
+		return;
 
 	mmdata = create_memmapsdata (procdata);
 	mmdata->info = info;
