@@ -60,7 +60,7 @@ renice_single_process (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter
 		gboolean success;
 
 		success = procdialog_create_root_password_dialog (
-			1, args->procdata, info->pid,
+			PROCMAN_ACTION_RENICE, args->procdata, info->pid,
 			args->nice_value);
 
 		if(success) return;
@@ -90,12 +90,23 @@ renice_single_process (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter
 
 
 void
-renice (ProcData *procdata, int pid, int nice)
+renice (ProcData *procdata, int nice)
 {
 	struct ReniceArgs args = { procdata, nice };
 
-	gtk_tree_selection_selected_foreach (procdata->selection, renice_single_process, 
-					     &args);
+	/* EEEK - ugly hack - make sure the table is not updated as a crash
+	** occurs if you first kill a process and the tree node is removed while
+	** still in the foreach function
+	*/
+	g_source_remove(procdata->timeout);
+
+	gtk_tree_selection_selected_foreach(procdata->selection, renice_single_process,
+					    &args);
+
+	procdata->timeout = g_timeout_add(procdata->config.update_interval,
+					  cb_timeout,
+					  procdata);
+
 	proctable_update_all (procdata);
 }
 
@@ -129,7 +140,7 @@ kill_single_process (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
 		gboolean success;
 
 		success = procdialog_create_root_password_dialog (
-			0, args->procdata, info->pid,
+			PROCMAN_ACTION_KILL, args->procdata, info->pid,
 			args->signal);
 
 		if(success) return;
